@@ -8,7 +8,7 @@ from cli_ui import warning, fatal
 
 from jinja2 import Environment, FileSystemLoader
 
-from gitlabform import EXIT_INVALID_INPUT
+from gitlabform.constants import EXIT_INVALID_INPUT
 from gitlabform.configuration import Configuration
 from gitlabform.gitlab import GitLab
 from gitlabform.gitlab.core import NotFoundException, UnexpectedResponseException
@@ -281,7 +281,7 @@ class FilesProcessor(AbstractProcessor):
         skip_build = configuration.get("files|" + file + "|skip_ci")
         skip_build_str = " [skip ci]" if skip_build else ""
 
-        return "%s%s" % (commit_message, skip_build_str)
+        return f"{commit_message}{skip_build_str}"
 
     @staticmethod
     def get_group(project_and_group):
