@@ -1,12 +1,12 @@
 from logging import debug
 from cli_ui import warning, fatal
 
-from gitlabform import EXIT_PROCESSING_ERROR, EXIT_INVALID_INPUT
+from gitlabform.constants import EXIT_PROCESSING_ERROR, EXIT_INVALID_INPUT
 from gitlabform.gitlab import GitLab
 from gitlabform.gitlab.core import NotFoundException
 
 
-class BranchProtector(object):
+class BranchProtector:
     new_api_keys = [
         "push_access_level",
         "merge_access_level",
